@@ -78,15 +78,15 @@ class HDDCDDModel(Model):
                 self.min_interval + '.')
 
         if model == "HD-CD":
-            self.temp_train_cols = ['HD', 'CD']
+            self.temp_train_cols = ['hd', 'cd']
             self.x_train_cols = list(
                 set(self.x_train_cols + self.temp_train_cols))
         elif model == "HD":
-            self.temp_train_cols = ['HD']
+            self.temp_train_cols = ['hd']
             self.x_train_cols = list(
                 set(self.x_train_cols + self.temp_train_cols))
         elif model == "CD":
-            self.temp_train_cols = ['CD']
+            self.temp_train_cols = ['cd']
             self.x_train_cols = list(
                 set(self.x_train_cols + self.temp_train_cols))
         else:
