@@ -1,4 +1,4 @@
-from Model import Model
+from .Model import Model
 import pandas as pd
 import numpy as np
 from sklearn.linear_model import LinearRegression
